@@ -9,7 +9,7 @@ from tornado.options import options
 from lesscode.db.base_sql_helper import BaseSqlHelper, echo_sql
 from lesscode.db.condition_wrapper import ConditionWrapper
 from lesscode.db.page import Page
-from lesscode.utils.aes import AES
+from lesscode.utils.encryption_algorithm import AES
 
 
 class ElasticsearchHelper(BaseSqlHelper):
