@@ -13,7 +13,6 @@ class EsPool(BaseConnectionPool):
     """
 
     def create_pool(self):
-        print("Elasticsearch API create_pool")
         """
         创建elasticsearch 异步连接池
         :param conn_info: 连接信息
@@ -26,4 +25,10 @@ class EsPool(BaseConnectionPool):
         else:
             raise NotImplementedError
 
-
+    def sync_create_pool(self):
+        info = self.conn_info
+        if info.async_enable:
+            pool = EsRequest(info.host, info.port, info.user, info.password)
+            return pool
+        else:
+            raise NotImplementedError
