@@ -78,3 +78,10 @@ def result_to_json(data):
         return query_set_to_list(data)
     else:
         return query_set_to_dict(data)
+
+
+def result_page(query, page_num=1, page_size=10):
+    offset_number = (page_num - 1) * page_size if page_num >= 1 else 0
+    data_list = query.limit(page_size).offset(offset_number).all()
+    data_count = query.count()
+    return {"count": data_count, "dataSource": data_list}
