@@ -35,7 +35,7 @@ define("eureka_config", default={}, type=dict, help="eureka配置")
 define("rms_register_enable", default=False, type=bool, help="是否启动资源注册")
 define("rms_register_server", default="http://127.0.0.1:8918", type=str, help="启动资源注册")
 define("running_env", default="local", type=str, help="运行环境")
-define("request_type", default="request", type=str, help="运行环境")
+define("request_type", default="request", type=str, help="请求类型")
 define("db", default=SQLAlchemy(), type=SQLAlchemy, help="SqlAlchemy")
 define("ks3_connect_config", default={}, type=dict, help="金山对象存储连接配置")
 define("scheduler", default=None, type=TornadoScheduler, help="Tornado任务调度")
